@@ -105,14 +105,16 @@ class DataFileProperty:
         self.sync(self.file_pro.path)
 
         logger.info(f'download for {file_pro.file_path_tar(absolute=False)}')
-        if self.data_type == 'kline':
-            exchan = LoadDataKline(self.exchange, csv_path=file_pro.file_path_csv())
-        else:
-            exchan = LoadTradeKline(self.exchange, csv_path=file_pro.file_path_csv())
         unix_start, unix_end = int(file_pro.start_date.timestamp() * 1000), int(file_pro.end_date.timestamp() * 1000)
+
+        if self.data_type == 'kline':
+            exchan = LoadDataKline(self.exchange, unix_start=unix_start,
+                                   unix_end=unix_end, csv_path=file_pro.file_path_csv(), timeframe=file_pro.timeframe)
+        else:
+            exchan = LoadTradeKline(self.exchange, unix_start=unix_start,
+                                    unix_end=unix_end, csv_path=file_pro.file_path_csv())
         # 下载
-        exchan.load_all(timeframe=file_pro.timeframe, unix_start=unix_start,
-                        unix_end=unix_end)
+        exchan.load_all()
         # 压缩
         with tarfile.open(file_pro.file_path_tar(), "w:xz") as tar:
             tar.add(file_pro.file_path_csv(), arcname=file_pro.arcname(file_pro.file_path_csv()))
