@@ -45,7 +45,7 @@ class LoadData:
 
     def write_data(self, data_list, cache=True):
         self.cache_data.extend(data_list)
-        if cache and len(self.cache_data) < 30000:
+        if cache and len(self.cache_data) < 10000:
             return
         if len(self.cache_data) == 0:
             return
@@ -90,17 +90,18 @@ class LoadDataKline(LoadData):
 class LoadTradeKline(LoadData):
     def __init__(self, *args, **kwargs):
         super(LoadTradeKline, self).__init__(*args, **kwargs)
-        # self.csv_writer = csv.DictWriter(open(self.csv_path, mode="w"), delimiter=",",
-        #                                  fieldnames=["symbol", "id", "timestamp", "type", "side", "price", "amount"])
-        self.table = TradeData(prefix=self.exchange.name,
-                               suffix=datetime.utcfromtimestamp(self.unix_start / 1000).strftime('%Y%m%d'))
+        self.csv_writer = csv.DictWriter(open(self.csv_path, mode="w"), delimiter=",",
+                                         fieldnames=["symbol", "id", "timestamp", "type", "side", "price", "amount"])
+        # self.table = TradeData(prefix=self.exchange.name,
+        #                       suffix=datetime.utcfromtimestamp(self.unix_start / 1000).strftime('%Y%m%d'))
 
     def load_close(self):
-        self.table.to_csv_all(file_path=self.csv_path)
+        # self.table.to_csv_all(file_path=self.csv_path)
+        pass
 
     def _write(self, data_list):
-        self.table.insert(values=data_list)
-        # self.csv_writer.writerows(data_list)
+        # self.table.insert(values=data_list)
+        self.csv_writer.writerows(data_list)
 
     def load(self, symbol, *args, **kwargs):
         unix_temp = self.unix_start
